==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class QueueConfigBuilder extends QueueConfigFluentImpl<QueueConfigBuilder> implements VisitableBuilder<QueueConfig,QueueConfigBuilder>{
  public QueueConfigBuilder() {
    this(false);
  }
  public QueueConfigBuilder(Boolean validationEnabled) {
    this(new QueueConfig(), validationEnabled);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new QueueConfig(), validationEnabled);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,QueueConfig instance) {
    this(fluent, instance, false);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,QueueConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBatchSendDeadline(instance.getBatchSendDeadline());
      fluent.withCapacity(instance.getCapacity());
      fluent.withMaxBackoff(instance.getMaxBackoff());
      fluent.withMaxRetries(instance.getMaxRetries());
      fluent.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      fluent.withMaxShards(instance.getMaxShards());
      fluent.withMinBackoff(instance.getMinBackoff());
      fluent.withMinShards(instance.getMinShards());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public QueueConfigBuilder(QueueConfig instance) {
    this(instance,false);
  }
  public QueueConfigBuilder(QueueConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBatchSendDeadline(instance.getBatchSendDeadline());
      this.withCapacity(instance.getCapacity());
      this.withMaxBackoff(instance.getMaxBackoff());
      this.withMaxRetries(instance.getMaxRetries());
      this.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      this.withMaxShards(instance.getMaxShards());
      this.withMinBackoff(instance.getMinBackoff());
      this.withMinShards(instance.getMinShards());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  QueueConfigFluent<?> fluent;
  Boolean validationEnabled;
  public QueueConfig build() {
    QueueConfig buildable = new QueueConfig(fluent.getBatchSendDeadline(),fluent.getCapacity(),fluent.getMaxBackoff(),fluent.getMaxRetries(),fluent.getMaxSamplesPerSend(),fluent.getMaxShards(),fluent.getMinBackoff(),fluent.getMinShards());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class QueueConfigBuilder extends QueueConfigFluent<QueueConfigBuilder> implements VisitableBuilder<QueueConfig,QueueConfigBuilder>{
  public QueueConfigBuilder() {
    this(false);
  }
  public QueueConfigBuilder(Boolean validationEnabled) {
    this(new QueueConfig(), validationEnabled);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new QueueConfig(), validationEnabled);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,QueueConfig instance) {
    this(fluent, instance, false);
  }
  public QueueConfigBuilder(QueueConfigFluent<?> fluent,QueueConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new QueueConfig());

    if (instance != null) {
      fluent.withBatchSendDeadline(instance.getBatchSendDeadline());
      fluent.withCapacity(instance.getCapacity());
      fluent.withMaxBackoff(instance.getMaxBackoff());
      fluent.withMaxRetries(instance.getMaxRetries());
      fluent.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      fluent.withMaxShards(instance.getMaxShards());
      fluent.withMinBackoff(instance.getMinBackoff());
      fluent.withMinShards(instance.getMinShards());
      fluent.withRetryOnRateLimit(instance.getRetryOnRateLimit());
      fluent.withBatchSendDeadline(instance.getBatchSendDeadline());
      fluent.withCapacity(instance.getCapacity());
      fluent.withMaxBackoff(instance.getMaxBackoff());
      fluent.withMaxRetries(instance.getMaxRetries());
      fluent.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      fluent.withMaxShards(instance.getMaxShards());
      fluent.withMinBackoff(instance.getMinBackoff());
      fluent.withMinShards(instance.getMinShards());
      fluent.withRetryOnRateLimit(instance.getRetryOnRateLimit());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public QueueConfigBuilder(QueueConfig instance) {
    this(instance,false);
  }
  public QueueConfigBuilder(QueueConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new QueueConfig());

    if (instance != null) {
      this.withBatchSendDeadline(instance.getBatchSendDeadline());
      this.withCapacity(instance.getCapacity());
      this.withMaxBackoff(instance.getMaxBackoff());
      this.withMaxRetries(instance.getMaxRetries());
      this.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      this.withMaxShards(instance.getMaxShards());
      this.withMinBackoff(instance.getMinBackoff());
      this.withMinShards(instance.getMinShards());
      this.withRetryOnRateLimit(instance.getRetryOnRateLimit());
      this.withBatchSendDeadline(instance.getBatchSendDeadline());
      this.withCapacity(instance.getCapacity());
      this.withMaxBackoff(instance.getMaxBackoff());
      this.withMaxRetries(instance.getMaxRetries());
      this.withMaxSamplesPerSend(instance.getMaxSamplesPerSend());
      this.withMaxShards(instance.getMaxShards());
      this.withMinBackoff(instance.getMinBackoff());
      this.withMinShards(instance.getMinShards());
      this.withRetryOnRateLimit(instance.getRetryOnRateLimit());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  QueueConfigFluent<?> fluent;
  Boolean validationEnabled;
  public QueueConfig build() {
    QueueConfig buildable = new QueueConfig(fluent.getBatchSendDeadline(),fluent.getCapacity(),fluent.getMaxBackoff(),fluent.getMaxRetries(),fluent.getMaxSamplesPerSend(),fluent.getMaxShards(),fluent.getMinBackoff(),fluent.getMinShards(),fluent.getRetryOnRateLimit());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
